#ifndef AUDIOLAYERWIDGET_H
#define AUDIOLAYERWIDGET_H

#include <QPushButton>
#include <QTimeEdit>
#include <QProgressBar>

#include "defines.h"
#include "slidergroup.h"
#include "clickablelabel.h"
#include "settings.h"
#include "filterbankwidget.h"

class AudioLayerWidget : public QWidget
{
    Q_OBJECT
    
public:
    explicit AudioLayerWidget(QWidget *parent = 0, int layer = 0);
    ~AudioLayerWidget();

    void setMediaFile(QString file);
    void setDuration(float dur);
    void setCurrentTime(float progress);
    void setPlaybackStatus(Status status);
    void setVol(float vol);
    void setPan(int pan);
    void setPitch(int pitch);
    void setFilterParam(int channel, int value);
    void setLevel(float db);
    void setBusName(uint bus, char *name);

private:
    Status m_status;
    Status m_oldStatus;
    int m_layer;
    QPushButton *m_suspendResumeButton;
    ClickableLabel *m_fileValue;
    ClickableLabel * m_folderValue;
    SliderGroup *m_volume;
    SliderGroup *m_pan;
    SliderGroup *m_pitch;
    SliderGroup *m_bus1;
    SliderGroup *m_bus2;
    QTimeEdit *m_progressTime;
    QTimeEdit *m_totalTimeValue;
    QProgressBar *m_progress;
    FilterBankWidget *m_filterBank;
    QLabel *m_level;
    QLabel *m_bus1Label;
    QLabel *m_bus2Label;

// From Ui
private slots:
    void openMediaDialog();
    void toggleSuspendResume();
    void volumeChanged(int vol);
    void bus1VolumeChanged(int vol);
    void bus2VolumeChanged(int vol);
    void panChanged(int pan);
    void pitchChanged(int pitch);
    void setBypass(bool value);

signals:
    void uiPlaybackChanged(int layer, Status s);
    void uiSliderChanged(int layer, Slider s, int value);
    void uiLoadMedia(int layer, QString s);
};

#endif // AUDIOLAYERWIDGET_H
